# Active Backlog

This page lists the backlog from oplog owners.
If you have a feature request, please open an issue, as described in [Contribution](contribution.md).

## Code

- test OperationHandler wrapper instead of Filter
- Timeouts (async only or for sync as well?)
    - https://stackoverflow.com/questions/45426713/how-to-gracefully-timeout-with-asyncio
    - https://stackoverflow.com/questions/492519/timeout-on-a-function-call
- Revisit the timing mechanism (performance timer vs clock timer)
- Support custom inheritors

## DevOps (prioritized)

- Justfile
- Precommit Hooks
- Check push policy
- Poetry
- Docker
- Dev Container
- Coverage % in build
